summaryrefslogtreecommitdiff
path: root/drivers/gpu/drm/exynos/exynos_drm_drv.h
diff options
context:
space:
mode:
authorSean Paul <seanpaul@chromium.org>2014-01-30 16:19:09 -0500
committerInki Dae <daeinki@gmail.com>2014-03-24 00:36:30 +0900
commit54c40dede10876868d62699e49b5f2b413f18b88 (patch)
tree87d61abc608d6e6c0a6f077c63f7b62fc8c5cf7f /drivers/gpu/drm/exynos/exynos_drm_drv.h
parente5b89916bc24f8b290d69229b6cbbdf35add1904 (diff)
downloadlwn-54c40dede10876868d62699e49b5f2b413f18b88.tar.gz
lwn-54c40dede10876868d62699e49b5f2b413f18b88.zip
drm/exynos: Rename display_op power_on to dpms
This patch renames the display_op power_on to dpms to accurately reflect what the function does. The side-effect of this patch is that the new hdmi dpms callback is now invoked twice in the dpms path. This is safe and will be dealt with when the exynos_drm shim goes away. Signed-off-by: Sean Paul <seanpaul@chromium.org> Reviewed-by: Tomasz Figa <t.figa@samsung.com> Signed-off-by: Inki Dae <inki.dae@samsung.com>
Diffstat (limited to 'drivers/gpu/drm/exynos/exynos_drm_drv.h')
-rw-r--r--drivers/gpu/drm/exynos/exynos_drm_drv.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/gpu/drm/exynos/exynos_drm_drv.h b/drivers/gpu/drm/exynos/exynos_drm_drv.h
index 5912841cdf2f..cf65f65d6c68 100644
--- a/drivers/gpu/drm/exynos/exynos_drm_drv.h
+++ b/drivers/gpu/drm/exynos/exynos_drm_drv.h
@@ -128,7 +128,7 @@ struct exynos_drm_overlay {
* @get_edid: get edid modes from display driver.
* @get_panel: get panel object from display driver.
* @check_mode: check if mode is valid or not.
* @power_on: display device on or off.
*/
struct exynos_drm_display_ops {
enum exynos_drm_output_type type;
@@ -138,7 +138,7 @@ struct exynos_drm_display_ops {
struct drm_connector *connector);
void *(*get_panel)(struct device *dev);
int (*check_mode)(struct device *dev, struct drm_display_mode *mode);
- int (*power_on)(struct device *dev, int mode);
+ int (*dpms)(struct device *dev, int mode);
};
/*
@@ -128,7 +128,7 @@ struct exynos_drm_overlay {
* @get_panel: get panel object from display driver.
* @check_mode: check if mode is valid or not.
- * @power_on: display device on or off.
+ * @dpms: display device on or off.
*/
struct exynos_drm_display_ops {